{{/*
Полное имя приложения создается по правилу <имя helm-charts>-<имя инстанса>
<Имя инстанса> = Release.Name
*/}}
{{- define "proxy.fullname" -}}
{{- printf "%s-%s" .Chart.Name .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "proxy.labels" -}}
helm.sh/chart: {{ include "proxy.chart" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{ include "proxy.selectorLabels" . }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "proxy.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "proxy.selectorLabels" -}}
app: {{ include "proxy.fullname" . }}
run: proxy
{{- end }}

{{/*
Имя configMap nginx artemis
*/}}
{{- define "proxy.proxy-config" -}}
{{- printf "%s-%s-%s" .Chart.Name .Release.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Задаем replica
*/}}
{{- define "proxy.replicaQuote" -}}

{{- if eq .Values.global.replicaQuote.quoteClass "large" -}}
  {{- .Values.replicaCount.largeQuota_proxy -}}
{{- else -}}
  {{- if eq .Values.global.replicaQuote.quoteClass "middle" -}}
    {{- .Values.replicaCount.middleQuota_proxy -}}
  {{- else -}}
    {{- .Values.replicaCount.miniQuota_proxy -}}
  {{- end -}}
{{- end -}}

{{- end -}}


