{{- define "imageSecret" }}
{{- with .Values.global.imageCredentials }}
{{- printf "{\"auths\":{\"%s\":{\"username\":\"%s\",\"password\":\"%s\",\"email\":\"%s\",\"auth\":\"%s\"}}}" .registry .username .password .email (printf "%s:%s" .username .password | b64enc) | b64enc }}
{{- end }}
{{- end }}

{{/*
Полное имя приложения создается по правилу <имя helm-charts>-<имя инстанса>
<Имя инстанса> = Release.Name
*/}}
{{- define "semnext.fullname" -}}
{{- printf "%s-%s" .Chart.Name .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Полное имя для сервиса semona
<Имя инстанса> = Release.Name
*/}}
{{- define "semnext.semona-fullname" -}}
{{- printf "%s-%s" "webservices" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Полное имя для сервиса engine
<Имя инстанса> = Release.Name
*/}}
{{- define "semnext.engine-fullname" -}}
{{- printf "%s-%s" "engine" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Полное имя для сервиса periodic
<Имя инстанса> = Release.Name
*/}}
{{- define "semnext.periodic-fullname" -}}
{{- printf "%s-%s" "periodic" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Полное имя для сервиса semux
<Имя инстанса> = Release.Name
*/}}
{{- define "semnext.semux-fullname" -}}
{{- printf "%s-%s" "semux" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Полное имя для сервиса migrator
<Имя инстанса> = Release.Name
*/}}
{{- define "semnext.migrator-fullname" -}}
{{- printf "%s-%s" "migrator" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Общие метки --labels
*/}}
{{- define "semnext.labels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/name: {{ .Chart.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
 метка webservices
*/}}
{{- define "semnext-semona.labels" -}}
{{ include "semnext.labels" . }}
app.kubernetes.io/component: webservices
{{ include "semnext-semona.selectorLabels" . }}
{{- end }}

{{/*
Selector webservices
*/}}
{{- define "semnext-semona.selectorLabels" -}}
app: {{ include "semnext.semona-fullname" . }}
run: webservices
{{- end }}

{{/*
 метка engine
*/}}
{{- define "semnext-engine.labels" -}}
{{ include "semnext.labels" . }}
app.kubernetes.io/component: engine
{{ include "semnext-engine.selectorLabels" . }}
{{- end }}

{{/*
Selector engine
*/}}
{{- define "semnext-engine.selectorLabels" -}}
app: {{ include "semnext.engine-fullname" . }}
{{- end }}

{{/*
 метка periodic
*/}}
{{- define "semnext-periodic.labels" -}}
{{ include "semnext.labels" . }}
app.kubernetes.io/component: periodic
{{ include "semnext-periodic.selectorLabels" . }}
{{- end }}

{{/*
Selector periodic
*/}}
{{- define "semnext-periodic.selectorLabels" -}}
app: {{ include "semnext.periodic-fullname" . }}
{{- end }}


{{/*
 метка semux
*/}}
{{- define "semnext-semux.labels" -}}
{{ include "semnext.labels" . }}
app.kubernetes.io/component: semux
{{ include "semnext-semux.selectorLabels" . }}
{{- end }}

{{/*
Selector semux
*/}}
{{- define "semnext-semux.selectorLabels" -}}
app: {{ include "semnext.semux-fullname" . }}
run: semux
{{- end }}

{{/*
Имя configMap для migrator
*/}}
{{- define "semnext.migrator-env" -}}
{{- printf "%s-%s-%s" "migrator" .Release.Name "env" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}


{{/*
Имя configMap для semnext
*/}}
{{- define "semnext.webservices-env" -}}
{{- printf "%s-%s-%s" "webservices" .Release.Name "env" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя configMap для periodic
*/}}
{{- define "semnext.periodic-env" -}}
{{- printf "%s-%s-%s" "periodic" .Release.Name "env" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя configMap для engine переменных
*/}}
{{- define "semnext.engine-env" -}}
{{- printf "%s-%s-%s" "engine" .Release.Name "env" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя configMap для engine application.yml
*/}}
{{- define "semnext.engine-app" -}}
{{- printf "%s-%s-%s" "engine" .Release.Name "application" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя config-standalone-full для periodic
*/}}
{{- define "semnext.semona-standalone-full" -}}
{{- printf "%s-%s" "standalone-full" .Release.Name  | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Имя config-standalone-full для webservices
*/}}
{{- define "semnext.semona-standalone-webservices" -}}
{{- printf "%s-%s" "standalone-full-webservices" .Release.Name  | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Return  the proper Storage Class
*/}}
{{- define "semnext.storageClass" -}}
  {{- if .Values.persistence.storageClass -}}
      {{- if (eq "-" .Values.persistence.storageClass) -}}
          {{- printf "storageClassName: \"\"" -}}
      {{- else }}
          {{- printf "storageClassName: %s" .Values.persistence.storageClass -}}
      {{- end -}}
  {{- end -}}
{{- end -}}

{{/*
квота для  engine
*/}}
{{- define "semnext-engine.replicaQuote" -}}
{{- if eq .Values.global.replicaQuote.quoteClass "large" -}}
  {{- .Values.replicaCount.largeQuota_engine -}}
{{- else -}}
  {{- if eq .Values.global.replicaQuote.quoteClass "middle" -}}
    {{- .Values.replicaCount.middleQuota_engine -}}
  {{- else -}}
    {{- .Values.replicaCount.miniQuota_engine -}}
  {{- end -}}
{{- end -}}
{{- end }}

{{/*
квота для  periodic
*/}}
{{- define "semnext-periodic.replicaQuote" -}}
{{- if eq .Values.global.replicaQuote.quoteClass "large" -}}
  {{- .Values.replicaCount.largeQuota_periodic -}}
{{- else -}}
  {{- if eq .Values.global.replicaQuote.quoteClass "middle" -}}
    {{- .Values.replicaCount.middleQuota_periodic -}}
  {{- else -}}
    {{- .Values.replicaCount.miniQuota_periodic -}}
  {{- end -}}
{{- end -}}
{{- end }}

{{/*
квота для  webservice
*/}}
{{- define "semnext-webservices.replicaQuote" -}}
{{- if eq .Values.global.replicaQuote.quoteClass "large" -}}
  {{- .Values.replicaCount.largeQuota_webservices -}}
{{- else -}}
  {{- if eq .Values.global.replicaQuote.quoteClass "middle" -}}
    {{- .Values.replicaCount.middleQuota_webservices -}}
  {{- else -}}
    {{- .Values.replicaCount.miniQuota_webservices -}}
  {{- end -}}
{{- end -}}
{{- end }}



{{- define "inspark-lic" }}
{{ if .Values.license.enabled }}
# Overrides
{{- range $key, $value := .Values.licence.data }}
# {{ $key }}
{{ tpl $value $ }}
{{- end }}
{{- end }}

{{- end }}
